import { System, SystemOptions, SystemBreakpoints, SystemZIndex, SystemFontSizes, SystemSpacing, SystemScale, SystemColorPalette, SystemBrandPalette, SystemType, SystemOptionalKey } from './types';
export { System, SystemOptions, SystemBreakpoints, SystemZIndex, SystemFontSizes, SystemSpacing, SystemScale, SystemColorPalette, SystemBrandPalette, SystemType, SystemOptionalKey, };
/** pxTo(): converts a `rem` or `em` value to `px` */
export declare const pxTo: (value: any, base?: number, unit?: string) => string;
/** toPx(): converts `px` to `rem` or `em` */
export declare const toPx: (value: any, base?: number) => string;
/** parseUnit(): parses a number and unit string, and returns the unit used */
export declare const parseUnit: (str: string) => string;
export default class DesignSystem<T extends System, K extends SystemOptions> {
    private opts;
    private ds;
    constructor(system: T, options?: K);
    /**
     * get()
     * get any value from the design system object
     */
    get(value: string, obj?: any): any;
    /**
     * set()
     * set any value in the design system object
     */
    set(location: string, value: any): void;
    /**
     * fontSize()
     * get a font-size value from the design system object
     */
    fontSize(size: string): string;
    /**
     * fs()
     * get a font-size value from the design system object
     * same as fontSize()
     */
    fs(size: string): string;
    /**
     * spacing()
     * get a spacing value from the design system object
     */
    spacing(val: string | number): string;
    /**
     * space()
     * get a spacing value from the design system object
     * same as spacing()
     */
    space(val: string | number): string;
    /**
     * color()
     * get a color from your color palette
     * `hue`: can contain a path to be traversed (eg: 'base.background.light'),
     * in that case the `variant` argument is ignored
     */
    color(hue: string, variant?: string): string;
    /**
     * brand()
     * get a color from your brand color palette
     */
    brand(color: string): string;
    /**
     * bp()
     * get a breakpoint value from the design system object
     */
    bp(breakpoint: string): string;
    /**
     * z()
     * get a z-index value from the design system object
     */
    z(z: string): string;
    /**
     * multiply()
     * multiply a given value
     */
    multiply(initial: any, multiplier: number): number;
    private parentCheck;
}
